From a015af309fd50cf80bbaee15bec5d4949e5b9d77 Mon Sep 17 00:00:00 2001
From: Angus Gratton <gus@projectgus.com>
Date: Tue, 1 Jul 2014 10:23:25 +1000
Subject: [PATCH 2/4] nrf51: Add workaround for PAN-16 where not all RAM blocks
 reliably enabled on reset

According to the NRF51822 datasheet, all RAM blocks should be enabled
on reset by default. However PAN-16 notes this isn't always the case.

This patch performs the erratum correction step so that all RAM is
accessible to the debugger.

Change-Id: I4f8be4ec3d1271da7fe5bc9a084fdcb2968535bb
Signed-off-by: Angus Gratton <gus@projectgus.com>
---
 tcl/target/nrf51_stlink.tcl | 8 ++++++++
 1 file changed, 8 insertions(+)

diff --git a/tcl/target/nrf51_stlink.tcl b/tcl/target/nrf51_stlink.tcl
index 7bd888e..40d6d0c 100644
--- a/tcl/target/nrf51_stlink.tcl
+++ b/tcl/target/nrf51_stlink.tcl
@@ -68,3 +68,11 @@ $_TARGETNAME configure -work-area-phys 0x20000000 -work-area-size $_WORKAREASIZE
 
 flash bank $_CHIPNAME.flash nrf51 0x00000000 0 1 1 $_TARGETNAME
 flash bank $_CHIPNAME.uicr nrf51 0x10001000 0 1 1 $_TARGETNAME
+
+proc enable_all_ram {} {
+	# nRF51822 Product Anomaly Notice (PAN) #16 explains that not all RAM banks
+	# are reliably enabled after reset on some revisions (contrary to spec.) So after
+	# resetting we enable all banks via the RAMON register
+	mww 0x40000524 0xF
+}
+$_TARGETNAME configure -event reset-end {  enable_all_ram }
-- 
2.0.0

